==> haskell-hls-haddock-comments-plugin-1.0.0.3-189-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-haddock-comments-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-haddock-comments-plugin
version:              1.0.0.3
visibility:           public
id:                   hls-haddock-comments-plugin-1.0.0.3-607dYva7L3M8kDeLG28WHI
key:                  hls-haddock-comments-plugin-1.0.0.3-607dYva7L3M8kDeLG28WHI
license:              Apache-2.0
maintainer:           berberman@yandex.com
author:               Potato Hatsue
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Haddock comments plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server>

category:             Development
abi:                  b691a31a48d36ab06589b9b7aee8af58
exposed:              True
exposed-modules:      Ide.Plugin.HaddockComments
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-haddock-comments-plugin-1.0.0.3

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-haddock-comments-plugin-1.0.0.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-haddock-comments-plugin
hs-libraries:
    HShls-haddock-comments-plugin-1.0.0.3-607dYva7L3M8kDeLG28WHI

depends:
    base-4.15.1.0 containers-0.6.4.1 ghc-9.0.2
    ghc-exactprint-0.6.4-A9nOK28ZPPgB8Jfy1jmshP
    ghcide-1.4.2.0-6q22EMZzITyEOnqA0C8YQs
    hls-plugin-api-1.2.0.0-9jTj6yw3RofA2iN4XUXSJb
    lsp-types-1.3.0.1-wzoOu9jp1S2jMCybNOnO4 text-1.2.5.0
    unordered-containers-0.2.19.1-DbIFFzq6LnrDtx1QZdVurE

haddock-interfaces:
    /usr/share/doc/haskell-hls-haddock-comments-plugin/html/hls-haddock-comments-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-haddock-comments-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-haddock-comments-plugin-1.0.0.3-200-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-haddock-comments-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-haddock-comments-plugin
version:              1.0.0.3
visibility:           public
id:                   hls-haddock-comments-plugin-1.0.0.3-88EKu9k5e6QLco6n38OR28
key:                  hls-haddock-comments-plugin-1.0.0.3-88EKu9k5e6QLco6n38OR28
license:              Apache-2.0
maintainer:           berberman@yandex.com
author:               Potato Hatsue
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Haddock comments plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server>

category:             Development
abi:                  c9cec9aadd00be9f7c64bf4820f21403
exposed:              True
exposed-modules:      Ide.Plugin.HaddockComments
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-haddock-comments-plugin-1.0.0.3

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-haddock-comments-plugin-1.0.0.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-haddock-comments-plugin
hs-libraries:
    HShls-haddock-comments-plugin-1.0.0.3-88EKu9k5e6QLco6n38OR28

depends:
    base-4.15.1.0 containers-0.6.4.1 ghc-9.0.2
    ghc-exactprint-0.6.4-19K69E1RPxP1CaWJdOQqm9
    ghcide-1.4.2.3-1htivssso5P9wAH1EUYuAs
    hls-plugin-api-1.2.0.1-6yBJVvsVXy76GMJvgZoZNC
    lsp-types-1.3.0.1-40f0HpYhVYQ4L3rwVe4AC7 text-1.2.5.0
    unordered-containers-0.2.19.1-FiUFtsHtx28IfDtF4iaH6c

haddock-interfaces:
    /usr/share/doc/haskell-hls-haddock-comments-plugin/html/hls-haddock-comments-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-haddock-comments-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
